@@ -2,55 +2,48 @@
 import functools
 import warnings
 from collections.abc import Callable
-from dataclasses import dataclass
-from dataclasses import field
+from dataclasses import dataclass, field
 from functools import cached_property
-from typing import Any
-from typing import Dict
-from typing import Union
+from typing import Any, Dict, Union
 
 import numpy as np
 import pandas as pd
+from pybaum import leaf_names, tree_just_flatten
+
 from estimagic.differentiation.derivatives import first_derivative
 from estimagic.estimation.msm_weighting import get_weighting_matrix
 from estimagic.exceptions import InvalidFunctionError
-from estimagic.inference.msm_covs import cov_optimal
-from estimagic.inference.msm_covs import cov_robust
-from estimagic.inference.shared import calculate_ci
-from estimagic.inference.shared import calculate_estimation_summary
-from estimagic.inference.shared import calculate_free_estimates
-from estimagic.inference.shared import calculate_p_values
-from estimagic.inference.shared import calculate_summary_data_estimation
-from estimagic.inference.shared import FreeParams
-from estimagic.inference.shared import get_derivative_case
-from estimagic.inference.shared import transform_covariance
-from estimagic.inference.shared import transform_free_cov_to_cov
-from estimagic.inference.shared import transform_free_values_to_params_tree
+from estimagic.inference.msm_covs import cov_optimal, cov_robust
+from estimagic.inference.shared import (
+    FreeParams,
+    calculate_ci,
+    calculate_estimation_summary,
+    calculate_free_estimates,
+    calculate_p_values,
+    calculate_summary_data_estimation,
+    get_derivative_case,
+    transform_covariance,
+    transform_free_cov_to_cov,
+    transform_free_values_to_params_tree,
+)
 from estimagic.optimization.optimize import minimize
-from estimagic.parameters.block_trees import block_tree_to_matrix
-from estimagic.parameters.block_trees import matrix_to_block_tree
-from estimagic.parameters.conversion import Converter
-from estimagic.parameters.conversion import get_converter
+from estimagic.parameters.block_trees import block_tree_to_matrix, matrix_to_block_tree
+from estimagic.parameters.conversion import Converter, get_converter
 from estimagic.parameters.space_conversion import InternalParams
 from estimagic.parameters.tree_registry import get_registry
-from estimagic.sensitivity.msm_sensitivity import calculate_actual_sensitivity_to_noise
 from estimagic.sensitivity.msm_sensitivity import (
+    calculate_actual_sensitivity_to_noise,
     calculate_actual_sensitivity_to_removal,
-)
-from estimagic.sensitivity.msm_sensitivity import (
     calculate_fundamental_sensitivity_to_noise,
-)
-from estimagic.sensitivity.msm_sensitivity import (
     calculate_fundamental_sensitivity_to_removal,
+    calculate_sensitivity_to_bias,
+    calculate_sensitivity_to_weighting,
 )
-from estimagic.sensitivity.msm_sensitivity import calculate_sensitivity_to_bias
-from estimagic.sensitivity.msm_sensitivity import calculate_sensitivity_to_weighting
-from estimagic.shared.check_option_dicts import check_numdiff_options
-from estimagic.shared.check_option_dicts import check_optimization_options
-from estimagic.utilities import get_rng
-from estimagic.utilities import to_pickle
-from pybaum import leaf_names
-from pybaum import tree_just_flatten
+from estimagic.shared.check_option_dicts import (
+    check_numdiff_options,
+    check_optimization_options,
+)
+from estimagic.utilities import get_rng, to_pickle
 
 
 def estimate_msm(
@@ -442,6 +435,7 @@ def _partial_kwargs(func, kwargs):
 
     In contrast to normal partial this works if kwargs in None. If func is not a
     callable it simply returns None.
+
     """
     if isinstance(func, Callable):
         if kwargs not in (None, {}):
@@ -570,6 +564,7 @@ class MomentsResult:
         Returns:
             Any: A pytree with the same structure as params containing standard errors
                 for the parameter estimates.
+
         """
         free_cov = self._get_free_cov(
             method=method,
@@ -625,6 +620,7 @@ class MomentsResult:
         Returns:
             Any: The covariance matrix of the estimated parameters as block-pytree or
                 numpy array.
+
         """
         free_cov = self._get_free_cov(
             method=method,
@@ -674,6 +670,7 @@ class MomentsResult:
 
         Returns:
             Any: The estimation summary as pytree of DataFrames.
+
         """
         summary_data = calculate_summary_data_estimation(
             self,
@@ -729,6 +726,7 @@ class MomentsResult:
                 confidence intervals.
             Any: Pytree with the same structure as params containing upper bounds of
                 confidence intervals.
+
         """
         free_cov = self._get_free_cov(
             method=method,
@@ -783,6 +781,7 @@ class MomentsResult:
         Returns:
             Any: Pytree with the same structure as params containing p-values.
             Any: Pytree with the same structure as params containing p-values.
+
         """
         free_cov = self._get_free_cov(
             method=method,
@@ -866,6 +865,7 @@ class MomentsResult:
             Any: The sensitivity measure as a pytree, numpy array or DataFrame.
                 In 2d formats, the sensitivity measures have one row per estimated
                 parameter and one column per moment.
+
         """
         if self._has_constraints:
             raise NotImplementedError(
@@ -913,7 +913,6 @@ class MomentsResult:
                 params_cov=params_cov,
             )
         elif kind == "removal_fundamental":
-
             raw = calculate_fundamental_sensitivity_to_removal(
                 jac=jac,
                 moments_cov=moments_cov,
@@ -921,7 +920,6 @@ class MomentsResult:
             )
 
         elif kind == "weighting":
-
             raw = calculate_sensitivity_to_weighting(
                 jac=jac,
                 weights=weights,
@@ -961,6 +959,7 @@ class MomentsResult:
 
         Args:
             path (str, pathlib.Path): A str or pathlib.path ending in .pkl or .pickle.
+
         """
         to_pickle(self, path=path)
 
@@ -976,7 +975,6 @@ def _calculate_free_cov_msm(
     bounds_handling,
     seed,
 ):
-
     if method == "optimal":
         internal_cov = cov_optimal(internal_jacobian, internal_weights)
     else:
