@@ -1,9 +1,8 @@
-from estimagic.logging.database_utilities import append_row
-from estimagic.logging.database_utilities import read_last_rows
-from estimagic.logging.database_utilities import update_row
+from estimagic.logging.read_from_database import read_last_rows
+from estimagic.logging.write_to_database import append_row, update_row
 
 
-def log_scheduled_steps_and_get_ids(steps, logging, db_kwargs):
+def log_scheduled_steps_and_get_ids(steps, logging, database):
     """Add scheduled steps to the steps table of the database and get their ids.
 
     The ids are only determined once the steps are written to the database and the
@@ -11,8 +10,8 @@ def log_scheduled_steps_and_get_ids(steps, logging, db_kwargs):
 
     Args:
         steps (list): List of dicts with entries for the steps table.
-        logging (bool): Whether to actually write to the databes.
-        db_kwargs (dict): Dict with the entries "database", "path" and "fast_logging"
+        logging (bool): Whether to actually write to the database.
+        database (DataBase):
 
     Returns:
         list: List of integers with the step ids.
@@ -26,14 +25,14 @@ def log_scheduled_steps_and_get_ids(steps, logging, db_kwargs):
             append_row(
                 data=data,
                 table_name="steps",
-                **db_kwargs,
+                database=database,
             )
 
         step_ids = read_last_rows(
             table_name="steps",
             n_rows=len(steps),
             return_type="dict_of_lists",
-            **db_kwargs,
+            database=database,
         )["rowid"]
     else:
         step_ids = list(range(len(steps)))
@@ -41,7 +40,7 @@ def log_scheduled_steps_and_get_ids(steps, logging, db_kwargs):
     return step_ids
 
 
-def update_step_status(step, new_status, db_kwargs):
+def update_step_status(step, new_status, database):
     step = int(step)
 
     assert new_status in ["scheduled", "running", "complete", "skipped"]
@@ -50,5 +49,5 @@ def update_step_status(step, new_status, db_kwargs):
         data={"status": new_status},
         rowid=step,
         table_name="steps",
-        **db_kwargs,
+        database=database,
     )
