@@ -3,13 +3,15 @@ import contextlib
 import warnings
 
 import numpy as np
+
 from estimagic.batch_evaluators import process_batch_evaluator
 from estimagic.config import IS_PYGMO_INSTALLED
 from estimagic.decorators import mark_minimizer
 from estimagic.exceptions import NotInstalledError
-from estimagic.optimization.algo_options import CONVERGENCE_RELATIVE_PARAMS_TOLERANCE
 from estimagic.optimization.algo_options import (
+    CONVERGENCE_RELATIVE_PARAMS_TOLERANCE,
     STOPPING_MAX_CRITERION_EVALUATIONS_GLOBAL,
+    get_population_size,
 )
 
 STOPPING_MAX_ITERATIONS_GENETIC = 250
@@ -56,7 +58,7 @@ def pygmo_gaco(
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
 
@@ -124,7 +126,7 @@ def pygmo_bee_colony(
     For details see :ref:`list_of_pygmo_algorithms`.
 
     """
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=20
     )
     algo_options = _create_algo_options(
@@ -176,7 +178,7 @@ def pygmo_de(
     For details see :ref:`list_of_pygmo_algorithms`.
 
     """
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=10
     )
 
@@ -247,7 +249,7 @@ def pygmo_sea(
 
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=10
     )
 
@@ -303,7 +305,7 @@ def pygmo_sga(
 
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
 
@@ -415,7 +417,7 @@ def pygmo_sade(
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
     mutation_variant_str_to_int = {
@@ -502,7 +504,7 @@ def pygmo_cmaes(
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
 
@@ -567,7 +569,7 @@ def pygmo_simulated_annealing(
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
 
@@ -638,7 +640,7 @@ def pygmo_pso(
 
     neighbor_param = _replace_none(neighbor_param, 4)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=10
     )
 
@@ -747,7 +749,7 @@ def pygmo_pso_gen(
     }
     algo_variant = _convert_str_to_int(algo_variant_str_to_int, algo_variant)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=10
     )
 
@@ -811,7 +813,7 @@ def pygmo_mbh(
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
     # the min default population size is this large to pass our sum of squares tests.
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=250
     )
 
@@ -871,7 +873,7 @@ def pygmo_xnes(
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
 
@@ -929,7 +931,7 @@ def pygmo_gwo(
     """
     _check_that_every_param_is_bounded(lower_bounds, upper_bounds)
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
     algo_options = _create_algo_options(
@@ -1045,7 +1047,7 @@ def pygmo_ihs(
     if population_size is not None:
         warnings.warn("The population size has no effect on IHS' performance.")
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=1
     )
 
@@ -1099,8 +1101,8 @@ def pygmo_de1220(
     ftol=1e-6,
     xtol=1e-6,
 ):
-    """Minimize a scalar function using Self-adaptive Differential Evolution,
-        pygmo flavor.
+    """Minimize a scalar function using Self-adaptive Differential Evolution, pygmo
+    flavor.
 
     For details see :ref:`list_of_pygmo_algorithms`.
 
@@ -1134,7 +1136,7 @@ def pygmo_de1220(
             for variant in allowed_variants
         ]
 
-    population_size = _determine_population_size(
+    population_size = get_population_size(
         population_size=population_size, x=x, lower_bound=64
     )
 
@@ -1175,7 +1177,7 @@ def _minimize_pygmo(
     upper_bounds,
     method,
     algo_options,
-    derivative=None,
+    derivative=None,  # noqa: ARG001
 ):
     """Minimize a function with pygmo.
 
@@ -1246,7 +1248,7 @@ def _create_problem(func, bounds, dim, batch_evaluator, n_cores):
         def get_bounds(self):
             return bounds
 
-        def gradient(self, dv):
+        def gradient(self, dv):  # noqa: ARG002
             raise ValueError("No pygmo optimizer should use a gradient.")
 
         def batch_fitness(self, dvs):
@@ -1291,6 +1293,7 @@ def _create_population(problem, population_size, x, seed, discard_start_params):
 
     Todo:
         - constrain random initial values to be in some bounds
+
     """
     if not discard_start_params:
         population_size = population_size - 1
@@ -1350,16 +1353,8 @@ def _check_that_every_param_is_bounded(lower_bounds, upper_bounds):
     assert np.isfinite(upper_bounds).all(), "The upper bounds must all be finite."
 
 
-def _determine_population_size(population_size, x, lower_bound):
-    if population_size is None:
-        population_size = int(np.clip(10 * (len(x) + 1), lower_bound, np.inf))
-    else:
-        population_size = int(population_size)
-    return population_size
-
-
 def _convert_str_to_int(str_to_int, value):
-    if value in str_to_int.keys():
+    if value in str_to_int:
         out = str_to_int[value]
     elif value not in str_to_int.values():
         raise ValueError(
