@@ -45,6 +45,7 @@ def minimize_trust_trsbox_fast(
     Returns:
         np.ndarray: Solution vector for the quadratic trust-region subproblem
             of shape (n,).
+
     """
     n = len(model_gradient)
     x_center = np.zeros(n)
@@ -98,7 +99,6 @@ def minimize_trust_trsbox_fast(
             gradient_sumsq * np.array([delta_sq]) <= 1.0e-6 * total_reduction**2
             and gradient_sumsq * np.array([delta_sq]) <= 1.0e-18
         ):
-
             need_alt_trust_step = False
             break
 
@@ -533,9 +533,10 @@ def _calc_greatest_criterion_reduction(
 ):
     """Calculate the greatest feasible reduction in the criterion function.
 
-    The largest reduction is found by looking at a range of equally spaced values
-    of ``tangent`` in the interval [0, ``bound_on_tangent``], where ``tangent`` is
-    the tangent of half the angle to the trust-region boundary.
+    The largest reduction is found by looking at a range of equally spaced values of
+    ``tangent`` in the interval [0, ``bound_on_tangent``], where ``tangent`` is the
+    tangent of half the angle to the trust-region boundary.
+
     """
     previous_reduction = None
     next_reduction = None
@@ -584,8 +585,9 @@ def _update_candidate_vectors_and_reduction_alt_step(
 ):
     """Update candidate vectors and the associated criterion reduction.
 
-    If the angle of the alternative iteration is restricted by a bound on a
-    free variable, that variable is fixed at the bound.
+    If the angle of the alternative iteration is restricted by a bound on a free
+    variable, that variable is fixed at the bound.
+
     """
     gradient_candidate += (cosine - 1.0) * hessian_reduced + sine * hess_s
     x_candidate_new = np.zeros(len(x_candidate))
