@@ -1,7 +1,6 @@
 """Auxiliary functions for the quadratic BNTR trust-region subsolver."""
 from functools import reduce
-from typing import NamedTuple
-from typing import Union
+from typing import NamedTuple, Union
 
 import numpy as np
 from estimagic.optimization.subsolvers._conjugate_gradient import (
@@ -27,6 +26,7 @@ def bntr(
     model,
     lower_bounds,
     upper_bounds,
+    x_candidate,
     *,
     conjugate_gradient_method,
     maxiter,
@@ -62,6 +62,7 @@ def bntr(
             for the parameter vector x.
         upper_bounds (np.ndarray): 1d array of shape (n,) with upper bounds
             for the parameter vector x.
+        x_candidate (np.ndarray): Initial guess for the solution of the subproblem.
         conjugate_gradient_method (str): Method for computing the conjugate gradient
             step. Available conjugate gradient methods are:
                 - "cg"
@@ -89,6 +90,7 @@ def bntr(
                 termination.
             - ``success`` (bool): Boolean indicating whether a solution has been found
                 before reaching maxiter.
+
     """
     options_update_radius = {
         "eta1": 1.0e-4,
@@ -105,8 +107,6 @@ def bntr(
         "default_radius": 100.00,
     }
 
-    x_candidate = np.zeros_like(model.linear_terms)
-
     (
         x_candidate,
         f_candidate,
@@ -915,6 +915,7 @@ def _get_fischer_burmeister_scalar(a, b):
 
     Returns:
         float: Value of the Fischer-Burmeister function for inputs a and b.
+
     """
     if a + b <= 0:
         fischer_burmeister = np.sqrt(a**2 + b**2) - (a + b)
@@ -940,5 +941,6 @@ def _evaluate_model_criterion(
 
     Returns:
         float: Criterion value of the main model.
+
     """
     return gradient.T @ x + 0.5 * x.T @ hessian @ x
