@@ -18,6 +18,7 @@ def bntr_fast(
     model,
     lower_bounds,
     upper_bounds,
+    x_candidate,
     *,
     conjugate_gradient_method,
     maxiter,
@@ -56,6 +57,7 @@ def bntr_fast(
             for the parameter vector x.
         upper_bounds (np.ndarray): 1d array of shape (n,) with upper bounds
             for the parameter vector x.
+        x_candidate (np.ndarray): Initial guess for the solution of the subproblem.
         conjugate_gradient_method (str): Method for computing the conjugate gradient
             step. Available conjugate gradient methods are:
                 - "cg"
@@ -83,6 +85,7 @@ def bntr_fast(
                 termination.
             - ``success`` (bool): Boolean indicating whether a solution has been found
                 before reaching maxiter.
+
     """
 
     model_gradient = model.linear_terms
@@ -98,6 +101,7 @@ def bntr_fast(
         model_hessian=model_hessian,
         lower_bounds=lower_bounds,
         upper_bounds=upper_bounds,
+        x_candidate=x_candidate,
         conjugate_gradient_method=conjugate_gradient_method,
         maxiter=maxiter,
         maxiter_gradient_descent=maxiter_gradient_descent,
@@ -125,6 +129,7 @@ def _bntr_fast_jitted(
     model_hessian,
     lower_bounds,
     upper_bounds,
+    x_candidate,
     conjugate_gradient_method,
     maxiter,
     maxiter_gradient_descent,
@@ -162,6 +167,7 @@ def _bntr_fast_jitted(
             for the parameter vector x.
         upper_bounds (np.ndarray): 1d array of shape (n,) with upper bounds
             for the parameter vector x.
+        x_candidate (np.ndarray): Initial guess for the solution of the subproblem.
         conjugate_gradient_method (str): Method for computing the conjugate gradient
             step. Available conjugate gradient methods are:
                 - "cg"
@@ -188,6 +194,7 @@ def _bntr_fast_jitted(
             termination.
         success (bool): Boolean indicating whether a solution has been found
             before reaching maxiter.
+
     """
 
     (
@@ -207,6 +214,7 @@ def _bntr_fast_jitted(
         model_hessian,
         lower_bounds,
         upper_bounds,
+        x_candidate,
         maxiter_gradient_descent,
         gtol_abs,
         gtol_rel,
@@ -339,6 +347,7 @@ def _take_preliminary_gradient_descent_step_and_check_for_solution(
     model_hessian,
     lower_bounds,
     upper_bounds,
+    x_candidate,
     maxiter_gradient_descent,
     gtol_abs,
     gtol_rel,
@@ -355,6 +364,7 @@ def _take_preliminary_gradient_descent_step_and_check_for_solution(
             for the parameter vector x.
         upper_bounds (np.ndarray): 1d array of shape (n,) with upper bounds
             for the parameter vector x.
+        x_candidate (np.ndarray): Initial guess for the solution of the subproblem.
         maxiter_gradient_descent (int): Maximum number of iterations in performing
             gradient descent step
         gtol_abs (float): Convergence tolerance for the absolute gradient norm.
@@ -366,7 +376,6 @@ def _take_preliminary_gradient_descent_step_and_check_for_solution(
         criterion_candidate (float): Candidate value for solution criterion.
         gradient_unprojected (np.ndarray):
 
-
     """
 
     default_radius = 100.0
@@ -383,8 +392,6 @@ def _take_preliminary_gradient_descent_step_and_check_for_solution(
     converged = False
     convergence_reason = 0
 
-    x_candidate = np.zeros(len(model_gradient))
-
     criterion_candidate = _evaluate_model_criterion(
         x_candidate, model_gradient, model_hessian
     )
@@ -691,6 +698,7 @@ def _compute_predicted_reduction_from_conjugate_gradient_step(
     inactive_bounds,
 ):
     """Compute predicted reduction induced by the Conjugate Gradient step.
+
     Args:
         conjugate_gradient_step (np.ndarray): Conjugate gradient step,of lenght n, with
             bounds applied to it.
@@ -1102,7 +1110,6 @@ def _update_trustregion_radius_and_gradient_descent(
 @njit
 def _get_fischer_burmeister_direction_vector(x, gradient, lower_bounds, upper_bounds):
     """Compute the constrained direction vector via the Fischer-Burmeister function."""
-
     direction = np.zeros(len(x))
     for i, (x_, g_, l_, u_) in enumerate(zip(x, gradient, lower_bounds, upper_bounds)):
         fischer_scalar = _get_fischer_burmeister_scalar(u_ - x_, -g_)
@@ -1128,6 +1135,7 @@ def _get_fischer_burmeister_scalar(a, b):
 
     Returns:
         float: Value of the Fischer-Burmeister function for inputs a and b.
+
     """
     if a + b <= 0:
         fischer_burmeister = np.sqrt(a**2 + b**2) - (a + b)
@@ -1154,5 +1162,6 @@ def _evaluate_model_criterion(
 
     Returns:
         float: Criterion value of the main model.
+
     """
     return gradient.T @ x + 0.5 * x.T @ hessian @ x
