@@ -1,10 +1,8 @@
 """Auxiliary functions for the quadratic GQTPAR trust-region subsolver."""
-from typing import NamedTuple
-from typing import Union
+from typing import NamedTuple, Union
 
 import numpy as np
-from scipy.linalg import cho_solve
-from scipy.linalg import solve_triangular
+from scipy.linalg import cho_solve, solve_triangular
 from scipy.linalg.lapack import dpotrf as compute_cholesky_factorization
 from scipy.optimize._trustregion_exact import estimate_smallest_singular_value
 
@@ -21,7 +19,7 @@ class DampingFactors(NamedTuple):
     upper_bound: Union[float, None] = None
 
 
-def gqtpar(model, *, k_easy=0.1, k_hard=0.2, maxiter=200):
+def gqtpar(model, x_candidate, *, k_easy=0.1, k_hard=0.2, maxiter=200):
     """Solve the quadratic trust-region subproblem via nearly exact iterative method.
 
     This subproblem solver is mainly based on Conn et al. (2000) "Trust region methods"
@@ -52,11 +50,10 @@ def gqtpar(model, *, k_easy=0.1, k_hard=0.2, maxiter=200):
     See pp. 194-197 in :cite:`Conn2000` for a more detailed description.
 
     Args:
-        main_model (NamedTuple): NamedTuple containing the parameters of the
-            main model, i.e.:
+        model (NamedTuple): NamedTuple containing the parameters of the main model, i.e.
             - ``linear_terms``, a np.ndarray of shape (n,) and
             - ``square_terms``, a np.ndarray of shape (n,n).
-        trustregion_radius (float): Trustregion radius, often referred to as delta.
+        x_candidate (np.ndarray): Initial guess for the solution of the subproblem.
         k_easy (float): topping criterion for the "easy" case.
         k_hard (float): Stopping criterion for the "hard" case.
         maxiter (int): Maximum number of iterations to perform. If reached,
@@ -67,11 +64,10 @@ def gqtpar(model, *, k_easy=0.1, k_hard=0.2, maxiter=200):
             - ``x`` (np.ndarray): Solution vector of the subproblem of shape (n,)
             - ``criterion`` (float): Minimum function value associated with the
                 solution.
+
     """
     hessian_info = HessianInfo()
 
-    x_candidate = np.zeros_like(model.linear_terms)
-
     # Small floating point number signaling that for vectors smaller
     # than that backward substituition is not reliable.
     # See Golub, G. H., Van Loan, C. F. (2013), "Matrix computations", p.165.
@@ -91,7 +87,6 @@ def gqtpar(model, *, k_easy=0.1, k_hard=0.2, maxiter=200):
     converged = False
 
     for _niter in range(maxiter):
-
         if hessian_info.already_factorized:
             hessian_info = hessian_info._replace(already_factorized=False)
         else:
@@ -174,6 +169,7 @@ def _get_initial_guess_for_lambdas(
             - "candidate"
             - "upper_bound"
             - "lower_bound"
+
     """
     gradient_norm = np.linalg.norm(main_model.linear_terms)
     model_hessian = main_model.square_terms
@@ -243,6 +239,7 @@ def add_lambda_and_factorize_hessian(main_model, hessian_info, lambdas):
             If k = 0, the factorization has been successful.
             A value k > 0 means that the leading k by k submatrix constitues the
             first non-positive definite leading submatrix of the hessian.
+
     """
     n = main_model.square_terms.shape[0]
 
@@ -383,8 +380,8 @@ def _get_new_lambda_candidate(lower_bound, upper_bound):
 
     Returns:
         float: New candidate for the damping factor lambda.
-    """
 
+    """
     lambda_new_candidate = max(
         np.sqrt(np.clip(lower_bound * upper_bound, 0, np.inf)),
         lower_bound + 0.01 * (upper_bound - lower_bound),
@@ -410,6 +407,7 @@ def _compute_gershgorin_bounds(main_model):
         Tuple:
         - lower_bound (float): Lower Gregoshgorin bound.
         - upper_bound (float): Upper Gregoshgorin bound.
+
     """
     model_hessian = main_model.square_terms
 
@@ -436,6 +434,7 @@ def _compute_newton_step(lambdas, p_norm, w_norm):
     Returns:
         float: Newton step computed according to formula (4.44) p.87
             from Nocedal and Wright (2006).
+
     """
     return lambdas.candidate + (p_norm / w_norm) ** 2 * (p_norm - 1)
 
@@ -523,6 +522,7 @@ def _compute_smallest_step_len_for_candidate_vector(x_candidate, z_min):
 
     Returns:
         float: Step length with the smallest magnitude.
+
     """
     ta, tb = _solve_scalar_quadratic_equation(x_candidate, z_min)
     step_len = min([ta, tb], key=abs)
@@ -555,6 +555,7 @@ def _solve_scalar_quadratic_equation(z, d):
         Tuple: The two values of t, sorted from low to high.
         - (float) Lower value of t.
         - (float) Higher value of t.
+
     """
     a = d.T @ d
     b = 2 * z.T @ d
@@ -593,6 +594,7 @@ def _compute_terms_to_make_leading_submatrix_singular(hessian_info, k):
             the leading k by k submatrix of the hessian to make it singular.
         - v (np.ndarray): A vector such that ``v.T B v = 0``. Where B is the
             hessian after ``delta`` is added to its element (k, k).
+
     """
     hessian_plus_lambda = hessian_info.hessian_plus_lambda
     upper_triangular = hessian_info.upper_triangular
