@@ -2,24 +2,34 @@
 
 TikTak (`Arnoud, Guvenen, and Kleineberg
 <https://www.nber.org/system/files/working_papers/w26340/w26340.pdf>`_)
-is an algorithm for solving global optimization problems. It performs local
-searches from a set of carefully-selected points in the parameter space.
 
-First implemented in Python by Alisdair McKay
-(`GitHub Repository <https://github.com/amckay/TikTak>`_)
+
+
+
+
+
+is an algorithm for solving global optimization problems. It performs local searches
+from a set of carefully-selected points in the parameter space.
+
+First implemented in Python by Alisdair McKay (
+
+`GitHub Repository <https://github.com/amckay/TikTak>`_)
+
 """
 import warnings
 from functools import partial
 
 import numpy as np
+from scipy.stats import qmc, triang
+
 from estimagic.batch_evaluators import process_batch_evaluator
 from estimagic.decorators import AlgoInfo
-from estimagic.optimization.optimization_logging import log_scheduled_steps_and_get_ids
-from estimagic.optimization.optimization_logging import update_step_status
+from estimagic.optimization.optimization_logging import (
+    log_scheduled_steps_and_get_ids,
+    update_step_status,
+)
 from estimagic.parameters.conversion import aggregate_func_output_to_value
 from estimagic.utilities import get_rng
-from scipy.stats import qmc
-from scipy.stats import triang
 
 
 def run_multistart_optimization(
@@ -31,7 +41,7 @@ def run_multistart_optimization(
     upper_sampling_bounds,
     options,
     logging,
-    db_kwargs,
+    database,
     error_handling,
 ):
     steps = determine_steps(options["n_samples"], options["n_optimizations"])
@@ -39,7 +49,7 @@ def run_multistart_optimization(
     scheduled_steps = log_scheduled_steps_and_get_ids(
         steps=steps,
         logging=logging,
-        db_kwargs=db_kwargs,
+        database=database,
     )
 
     if options["sample"] is not None:
@@ -62,7 +72,7 @@ def run_multistart_optimization(
         update_step_status(
             step=scheduled_steps[0],
             new_status="running",
-            db_kwargs=db_kwargs,
+            database=database,
         )
 
     if "criterion" in problem_functions:
@@ -84,7 +94,7 @@ def run_multistart_optimization(
         update_step_status(
             step=scheduled_steps[0],
             new_status="complete",
-            db_kwargs=db_kwargs,
+            database=database,
         )
 
     scheduled_steps = scheduled_steps[1:]
@@ -109,7 +119,7 @@ def run_multistart_optimization(
                 update_step_status(
                     step=step,
                     new_status="skipped",
-                    db_kwargs=db_kwargs,
+                    database=database,
                 )
 
     batched_sample = get_batched_optimization_sample(
@@ -148,7 +158,6 @@ def run_multistart_optimization(
 
     opt_counter = 0
     for batch in batched_sample:
-
         weight = weight_func(opt_counter, n_optimizations)
         starts = [weight * state["best_x"] + (1 - weight) * x for x in batch]
 
@@ -180,7 +189,7 @@ def run_multistart_optimization(
                     update_step_status(
                         step=step,
                         new_status="skipped",
-                        db_kwargs=db_kwargs,
+                        database=database,
                     )
             break
 
@@ -208,6 +217,7 @@ def determine_steps(n_samples, n_optimizations):
 
     Returns:
         list: List of dictionaries with information on each step.
+
     """
     exploration_step = {
         "type": "exploration",
@@ -257,6 +267,7 @@ def draw_exploration_sample(
     Returns:
         np.ndarray: Numpy array of shape (n_samples, n_params).
             Each row represents a vector of parameter values.
+
     """
     valid_rules = ["sobol", "halton", "latin_hypercube", "random"]
     valid_distributions = ["uniform", "triangular"]
