@@ -1,15 +1,15 @@
 """Check compatibility of pc with each other and with bounds and fixes.
 
 See the module docstring of process_constraints for naming conventions.
+
 """
 from functools import partial
 
 import numpy as np
 import pandas as pd
-from estimagic.exceptions import InvalidConstraintError
-from estimagic.exceptions import InvalidParamsError
-from estimagic.utilities import cov_params_to_matrix
-from estimagic.utilities import sdcorr_params_to_matrix
+
+from estimagic.exceptions import InvalidConstraintError, InvalidParamsError
+from estimagic.utilities import cov_params_to_matrix, sdcorr_params_to_matrix
 
 
 def check_constraints_are_satisfied(flat_constraints, param_values, param_names):
@@ -121,8 +121,6 @@ def check_types(constraints):
     Raises:
         TypeError if invalid constraint types are encountered
 
-
-
     """
     valid_types = {
         "covariance",
@@ -233,7 +231,7 @@ def check_fixes_and_bounds(constr_info, transformations, parnames):
     invalid = df.query("lower_bounds >= upper_bounds")[["lower_bounds", "upper_bounds"]]
     msg = (
         "lower_bound must be strictly smaller than upper_bound. "
-        + f"This is violated for:\n{invalid}"
+        f"This is violated for:\n{invalid}"
     )
     if len(invalid) > 0:
         raise InvalidConstraintError(msg)
