@@ -1,13 +1,14 @@
 """Functions to consolidate user provided constraints.
 
-Consolidation means that redundant constraints are dropped
-and other constraints are collected in meaningful bundles.
+Consolidation means that redundant constraints are dropped and other constraints are
+collected in meaningful bundles.
 
 Check the module docstring of process_constraints for naming conventions.
 
 """
 import numpy as np
 import pandas as pd
+
 from estimagic.exceptions import InvalidConstraintError
 from estimagic.utilities import number_of_triangular_elements_to_dimension
 
@@ -175,7 +176,7 @@ def _unite_first_with_all_intersecting_elements(indices):
         else:
             new_others.append(idx)
 
-    return [new_first] + new_others
+    return [new_first, *new_others]
 
 
 def _consolidate_fixes_with_equality_constraints(
@@ -198,10 +199,7 @@ def _consolidate_fixes_with_equality_constraints(
     """
     fixed_value = np.full(len(parvec), np.nan)
     for fix in fixed_constraints:
-        if "value" in fix:
-            fixed_value[fix["index"]] = fix["value"]
-        else:
-            fixed_value[fix["index"]] = parvec[fix["index"]]
+        fixed_value[fix["index"]] = fix.get("value", parvec[fix["index"]])
 
     for eq in equality_constraints:
         if np.isfinite(fixed_value[eq["index"]]).any():
@@ -275,7 +273,7 @@ def simplify_covariance_and_sdcorr_constraints(
     for constr in to_simplify:
         dim = number_of_triangular_elements_to_dimension(len(constr["index"]))
         if constr["type"] == "covariance":
-            diag_positions = [0] + np.cumsum(range(2, dim + 1)).tolist()
+            diag_positions = [0, *np.cumsum(range(2, dim + 1)).tolist()]
             diag_indices = np.array(constr["index"])[diag_positions].tolist()
             off_indices = [i for i in constr["index"] if i not in diag_positions]
         if constr["type"] == "sdcorr":
@@ -488,6 +486,7 @@ def _plug_fixes_into_linear_weights_and_rhs(
     Returns:
         new_weights (pd.DataFrame)
         new_rhs (pd.DataFrame)
+
     """
     ilocs = np.arange(len(fixed_value))
     fixed_ilocs = ilocs[is_fixed_to_value].tolist()
