@@ -2,8 +2,7 @@
 import inspect
 from functools import partial
 
-from estimagic.exceptions import InvalidFunctionError
-from estimagic.exceptions import InvalidKwargsError
+from estimagic.exceptions import InvalidFunctionError, InvalidKwargsError
 from estimagic.utilities import propose_alternatives
 
 
@@ -30,7 +29,6 @@ def process_func_of_params(func, kwargs, name="your function", skip_checks=False
     out = partial(func, **kept)
 
     if not skip_checks:
-
         unpartialled_args = get_unpartialled_arguments(out)
         no_default_args = get_arguments_without_default(out)
 
