@@ -8,6 +8,11 @@ import numpy as np
 import pandas as pd
 
 
+suppress_performance_warnings = np.testing.suppress_warnings()
+suppress_performance_warnings.filter(category=pd.errors.PerformanceWarning)
+
+
+@suppress_performance_warnings
 def estimation_table(
     models,
     *,
@@ -107,7 +112,7 @@ def estimation_table(
         confidence_intervals (bool): If True, display confidence intervals as inference
             values. Display standard errors otherwise. Default False.
         significance_levels (list): a list of floats for p value's significance cut-off
-            values.This is used to generate the significance stars. Default is
+            values. This is used to generate the significance stars. Default is
             [0.1,0.05,0.01].
         append_notes (bool): A boolean variable for printing p value cutoff explanation
             and additional notes, if applicable. Default is True.
@@ -121,7 +126,7 @@ def estimation_table(
             used as row names in the table.
         number_format (int, str, iterable or callable): A callable, iterable, integer
             or string that is used to apply string formatter(s) to floats in the
-            table. Defualt ("{0:.3g}", "{0:.5f}", "{0:.4g}").
+            table. Default ("{0:.3g}", "{0:.5f}", "{0:.4g}").
         add_trailing_zeros (bool): If True, format floats such that they have same
             number of digits after the decimal point. Default True.
         siunitx_warning (bool): If True, print warning about LaTex preamble to add for
@@ -261,7 +266,7 @@ def render_latex(
         significance_levels (list or tuple): a list of floats for p value's significance
             cutt-off values. Default is [0.1,0.05,0.01].
         custom_notes (list): A list of strings for additional notes. Default is None.
-        siunitx_watning (bool): If True, print warning about LaTex preamble to add for
+        siunitx_warning (bool): If True, print warning about LaTex preamble to add for
             proper compilation of  when working with siunitx package. Default True.
         show_index_names (bool): If True, display index names in the table.
         show_col_names (bool): If True, the column names are displayed.
@@ -348,8 +353,7 @@ def render_latex(
     latex_str = latex_str.split("\\bottomrule")[0]
     if show_footer:
         footer = footer.copy(deep=True)
-        for _, r in footer.iterrows():
-            r = _center_align_integers(r)
+        footer = footer.apply(_center_align_integers_and_non_numeric_strings, axis=1)
         footer_styler = footer.style
         stats_str = footer_styler.to_latex(**default_options)
         if "\\midrule" in stats_str:
@@ -384,7 +388,7 @@ def render_html(
     show_col_names=True,
     show_col_groups=True,
     escape_special_characters=True,
-    **kwargs,
+    **kwargs,  # noqa: ARG001
 ):
     """Return estimation table in html format as string.
 
@@ -465,6 +469,7 @@ def render_html(
 
 def _process_model(model):
     """Check model validity, convert to dictionary.
+
     Args
         model: Estimation result. See docstring of estimation_table for more info.
     Returns:
@@ -486,11 +491,11 @@ def _process_model(model):
             name = info.pop("name")
         except (KeyboardInterrupt, SystemExit):
             raise
-        except Exception:
+        except Exception as e:
             raise TypeError(
                 f"""Model can  be of type dict,  pd.DataFrame
                 or a statsmodels result. Model {model} is of type {type(model)}."""
-            )
+            ) from e
     if "pvalue" in params.columns:
         params = params.rename(columns={"pvalue": "p_value"})
     processed_model = {"params": params, "info": info, "name": name}
@@ -543,7 +548,7 @@ def _get_estimation_table_body_and_footer(
         number_format (int, str, iterable or callable): A callable, iterable, integer
             or callable that is used to apply string formatter(s) to floats in the
             table.
-        add_trailing_zeros (bool): If True, format floats such that they haave same
+        add_trailing_zeros (bool): If True, format floats such that they have same
             number of digits after the decimal point.
 
     Returns:
@@ -552,7 +557,6 @@ def _get_estimation_table_body_and_footer(
         footer (DataFrame): DataFrame with formatted strings of summary statistics to
             display at the bottom of estimation table.
 
-
     """
     body, max_trail = _build_estimation_table_body(
         models,
@@ -597,7 +601,6 @@ def _build_estimation_table_body(
     number_format,
     add_trailing_zeros,
 ):
-
     """Create body bloc significance stars and inference values.
 
     Applies number formatting to parameters. Concatinates inference values
@@ -625,7 +628,7 @@ def _build_estimation_table_body(
         number_format (int, str, iterable or callable): A callable, iterable, integer
             or callable that is used to apply string formatter(s) to floats in the
             table.
-        add_trailing_zeros (bool): If True, format floats such that they haave same
+        add_trailing_zeros (bool): If True, format floats such that they have same
             number of digits after the decimal point.
 
     Returns:
@@ -720,8 +723,6 @@ def _build_estimation_table_footer(
         for mod in models
     ]
     stats = pd.concat(to_concat, axis=1)
-    for _, r in stats.iterrows():
-        r = _unformat_integers(r)
     return stats
 
 
@@ -756,8 +757,8 @@ def _get_common_index(dfs):
 def _get_cols_to_format(show_inference, confidence_intervals):
     """Get the list of names of columns that need to be formatted.
 
-    By default, formatting is applied to  parameter values. If inference values
-    need to displayed, adds confidence intervals or standard erros to the list.
+    By default, formatting is applied to  parameter values. If inference values need to
+    displayed, adds confidence intervals or standard erros to the list.
 
     """
     cols = ["value"]
@@ -770,12 +771,18 @@ def _get_cols_to_format(show_inference, confidence_intervals):
 
 
 def _apply_number_formatting_frames(dfs, columns, number_format, add_trailing_zeros):
-    """Apply string formatter to specific columns of a list of DataFrames"""
+    """Apply string formatter to specific columns of a list of DataFrames."""
 
-    raw_formatted = [_apply_number_format(df[columns], number_format) for df in dfs]
+    raw_formatted = [
+        _apply_number_format(df[columns], number_format, format_integers=False)
+        for df in dfs
+    ]
     max_trail = int(max([_get_digits_after_decimal(df) for df in raw_formatted]))
     if add_trailing_zeros:
-        formatted = [_apply_number_format(df, max_trail) for df in raw_formatted]
+        formatted = [
+            _apply_number_format(df, max_trail, format_integers=True)
+            for df in raw_formatted
+        ]
     else:
         formatted = raw_formatted
     return formatted, max_trail
@@ -984,7 +991,7 @@ def _convert_frame_to_string_series(
 
         df (DataFrame): params DataFrame of the model
         significance_levels (list): see main docstring
-        number_format (int): see main docstring
+        number_format (int, str, iterable or callable): see main docstring
         show_inference (bool): see main docstring
         confidence_intervals (bool): see main docstring
         show_stars (bool): see main docstring
@@ -995,7 +1002,7 @@ def _convert_frame_to_string_series(
     """
     value_sr = df["value"]
     if show_stars:
-        sig_bins = [-1] + sorted(significance_levels) + [2]
+        sig_bins = [-1, *sorted(significance_levels)] + [2]
         value_sr += "$^{"
         value_sr += (
             pd.cut(
@@ -1046,7 +1053,6 @@ def _combine_series(value_sr, inference_sr):
         series: combined string series of param and inference values
 
     """
-
     value_df = value_sr.to_frame(name="")
     original_cols = value_df.columns
     value_df.reset_index(drop=False, inplace=True)
@@ -1079,7 +1085,12 @@ def _create_statistics_sr(
         stats_options (dict): see main docstring
         significance_levels (list): see main docstring
         show_stars (bool): see main docstring
-        number_format (int): see main focstring
+        number_format (int, str, iterable or callable): see main docstring
+        add_trailing_zeros (bool): If True, format floats such that they haave same
+            number of digits after the decimal point.
+        max_trail (int): If add_trailing_zeros is True, add corresponding number of
+            trailing zeros to floats in the stats DataFrame to have number of digits
+            after a decimal point equal to max_trail for each float.
 
     Returns:
         series: string series with summary statistics values and additional info
@@ -1094,17 +1105,20 @@ def _create_statistics_sr(
         show_dof = None
     for k in stats_options:
         stats_values[stats_options[k]] = model["info"].get(k, np.nan)
+
     raw_formatted = _apply_number_format(
-        pd.DataFrame(pd.Series(stats_values)), number_format
+        pd.DataFrame(pd.Series(stats_values)), number_format, format_integers=False
     )
     if add_trailing_zeros:
-        formatted = _apply_number_format(raw_formatted, max_trail)
+        formatted = _apply_number_format(
+            raw_formatted, max_trail, format_integers=False
+        )
     else:
         formatted = raw_formatted
     stats_values = formatted.to_dict()[0]
     if "fvalue" in model["info"] and "F Statistic" in stats_values:
         if show_stars and "f_pvalue" in model["info"]:
-            sig_bins = [-1] + sorted(significance_levels) + [2]
+            sig_bins = [-1, *sorted(significance_levels)] + [2]
             sig_icon_fstat = "*" * (
                 len(significance_levels)
                 - np.digitize(model["info"]["f_pvalue"], sig_bins)
@@ -1127,7 +1141,7 @@ def _create_statistics_sr(
                 stats_values["Residual Std. Error"], int(model["info"]["df_resid"])
             )
     stat_sr = pd.Series(stats_values)
-    # the follwing is to make sure statistics dataframe has as many levels of
+    # the following is to make sure statistics dataframe has as many levels of
     # indices as the parameters dataframe.
     stat_ind = np.empty((len(stat_sr), model["params"].index.nlevels - 1), dtype=str)
     stat_ind = np.concatenate(
@@ -1226,8 +1240,8 @@ def _generate_notes_latex(
                     raise ValueError(
                         f"""Each custom note can only be of string type.
                         The following notes:
-                        {[n for n in custom_notes if not type(n)==str]} are of types
-                        {[type(n) for n in custom_notes if not type(n)==str]}
+                        {[n for n in custom_notes if type(n) != str]} are of types
+                        {[type(n) for n in custom_notes if type(n) != str]}
                         respectively."""
                     )
                 for n in custom_notes:
@@ -1240,7 +1254,7 @@ def _generate_notes_latex(
                     amp_n, n_columns, custom_notes
                 )
             else:
-                raise ValueError(
+                raise TypeError(
                     f"""Custom notes can be either a string or a list of strings.
                     Not: {type(custom_notes)}."""
                 )
@@ -1286,8 +1300,8 @@ def _generate_notes_html(
                     raise ValueError(
                         f"""Each custom note can only be of string type.
                         The following notes:
-                        {[n for n in custom_notes if not type(n)==str]} are of types
-                        {[type(n) for n in custom_notes if not type(n)==str]}
+                        {[n for n in custom_notes if type(n) != str]} are of types
+                        {[type(n) for n in custom_notes if type(n) != str]}
                         respectively."""
                     )
                 notes_text += """
@@ -1310,7 +1324,7 @@ def _generate_notes_html(
                     n_columns + n_levels - 1, custom_notes
                 )
             else:
-                raise ValueError(
+                raise TypeError(
                     f"""Custom notes can be either a string or a list of strings,
                     not {type(custom_notes)}."""
                 )
@@ -1349,31 +1363,41 @@ def _extract_info_from_sm(model):
     return info
 
 
-def _apply_number_format(df, number_format):
+def _apply_number_format(df_raw, number_format, format_integers):
     """Apply string format to DataFrame cells.
 
     Args:
-        df (DataFrame): The DataFrame with float values to format.
-        number_format(str, list, tuple, callable or int): User defined number format
+        df_raw (DataFrame): The DataFrame with float values to format.
+        number_format (str, list, tuple, callable or int): User defined number format
             to apply to the DataFrame.
+        format_integers (bool): Apply number format also to integers
 
     Returns:
         df_formatted (DataFrame): Formatted DataFrame.
+
     """
     processed_format = _process_number_format(number_format)
+    df_raw = df_raw.copy(deep=True)
     if isinstance(processed_format, (list, tuple)):
-        df_formatted = df.copy(deep=True).astype("float")
+        df_formatted = df_raw.copy(deep=True).astype("float")
         for formatter in processed_format[:-1]:
             df_formatted = df_formatted.applymap(formatter.format).astype("float")
         df_formatted = df_formatted.astype("float").applymap(
             processed_format[-1].format
         )
     elif isinstance(processed_format, str):
-        df_formatted = df.astype("str").applymap(
+        df_formatted = df_raw.astype("str").applymap(
             partial(_format_non_scientific_numbers, format_string=processed_format)
         )
     elif callable(processed_format):
-        df_formatted = df.applymap(processed_format)
+        df_formatted = df_raw.applymap(processed_format)
+
+    # Don't format integers: set to original value
+    if not format_integers:
+        integer_locs = df_raw.applymap(_is_integer)
+        df_formatted[integer_locs] = (
+            df_raw[integer_locs].astype(float).applymap("{:.0f}".format)
+        )
     return df_formatted
 
 
@@ -1429,38 +1453,23 @@ def _get_digits_after_decimal(df):
     return max_trail
 
 
-def _center_align_integers(sr):
-    """Align integer numbers at the center of model column."""
+def _center_align_integers_and_non_numeric_strings(sr):
+    """Align integer numbers and strings at the center of model column."""
+    sr = deepcopy(sr)
     for i in sr.index:
-        res_numeric = re.findall(
-            r"[-+]?[.]?[\d]+(?:,\d\d\d)*[\.]?\d*(?:[eE][-+]?\d+)?", sr[i]
-        )
-        if res_numeric:
-            num = res_numeric[0]
-            char = sr[i].split(num)[1]
-            if int(float(num)) == float(num):
-                sr[i] = f"\\multicolumn{{1}}{{c}}{{{str(int(float(num)))+char}}}"
-    return sr
-
-
-def _unformat_integers(sr):
-    """Remove trailing zeros from integer numbers."""
-    for i in sr.index:
-        res_numeric = re.findall(
-            r"[-+]?[.]?[\d]+(?:,\d\d\d)*[\.]?\d*(?:[eE][-+]?\d+)?", sr[i]
-        )
-        if res_numeric:
-            num = res_numeric[0]
-            char = sr[i].split(num)[1]
-            if int(float(num)) == float(num):
-                sr[i] = str(int(float(num))) + char
+        if _is_integer(sr[i]):
+            sr[i] = f"\\multicolumn{{1}}{{c}}{{{str(int(float(sr[i])))}}}"
+        else:
+            string_without_stars = sr[i].split("$", 1)[0]
+            if not string_without_stars.replace(".", "").isnumeric():
+                sr[i] = f"\\multicolumn{{1}}{{c}}{{{sr[i]}}}"
     return sr
 
 
 def _get_updated_styler(
     df, show_index_names, show_col_names, show_col_groups, escape_special_characters
 ):
-    """Return pandas.Styler object based ont the data and styling options"""
+    """Return pandas.Styler object based ont the data and styling options."""
     styler = df.style
     if not show_index_names:
         styler = styler.hide(names=True)
@@ -1471,3 +1480,12 @@ def _get_updated_styler(
     for ax in [0, 1]:
         styler = styler.format_index(escape=escape_special_characters, axis=ax)
     return styler
+
+
+def _is_integer(num):
+    """Check if number is an integer (including a float with only zeros as digits)"""
+    try:
+        out = int(float(num)) == float(num)
+    except ValueError:
+        out = False
+    return out
